==> wsk_material-0.8.0.tar.gz: README.md <==
# Web Starter Kit - Material Design

A port of Googles Web Starter Kit (Material branch) to Dart<br>
You can find the original version here on [GitHub][wskmaterial]

Web Starter Kit strives to give you a high performance starting point out of the box
Responsive layout is included with the kit that adapts to fit the device your user is viewing it on. 

[Demo][wskdemo] (transpiled JS-Version)

[![promoimage]][wskdemo]

If you work with AngularDart the [wsk-angular-Version][wskangular] could be interesting for you.

## Usage

Please check out my [samples][samples]. They are short and easy to read.
Since v0.6.1 every [sample][samples] shows a little "Load indicator"!

Just a very basic theming-sample can be found [here][themingsample]
```shell
    assets$ sassc scss/styleguide.scss css/styleguide.css
    assets$ autoprefixer css/styleguide.css
```

## Features and bugs

Please file feature requests and bugs at the [issue tracker][tracker].

###License###

    Copyright 2015 Michael Mitterer (office@mikemitterer.at),
    IT-Consulting and Development Limited, Austrian Branch

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing,
    software distributed under the License is distributed on an
    "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    either express or implied. See the License for the specific language
    governing permissions and limitations under the License.


If this plugin is helpful for you - please [(Circle)](http://gplus.mikemitterer.at/) me
or **star** this repo here on GitHub


[tracker]: https://github.com/MikeMitterer/dart-wsk-material/issues
[wskmaterial]: https://github.com/google/web-starter-kit/tree/material-sprint
[wskdemo]: http://wsk.mikemitterer.at/
[wskangular]: https://github.com/MikeMitterer/dart-wsk-angular
[themingsample]: https://github.com/MikeMitterer/dart-wsk-angular/tree/master/example/styleguide/assets/scss
[samples]: https://github.com/MikeMitterer/dart-wsk-material/tree/master/example
[promoimage]: https://github.com/MikeMitterer/dart-wsk-material/blob/master/lib/images/wsk.mikemitterer.at-720px.jpg?raw=true

==> wsk_material-0.8.2.tar.gz: README.md <==
# Web Starter Kit - Material Design

A port of Googles Web Starter Kit (Material branch) to Dart<br>
You can find the original version here on [GitHub][wskmaterial]

Web Starter Kit strives to give you a high performance starting point out of the box
Responsive layout is included with the kit that adapts to fit the device your user is viewing it on. 

[Demo][wskdemo] (transpiled JS-Version)

[![ScreenShot][promoimage]][wskdemo]

If you work with AngularDart the [wsk-angular-Version][wskangular] could be interesting for you.

## Usage

Please check out my [samples][samples]. They are short and easy to read.
Since v0.6.1 every [sample][samples] shows a little "Load indicator"!

Just a very basic theming-sample can be found [here][themingsample]
```shell
    assets$ sassc scss/styleguide.scss css/styleguide.css
    assets$ autoprefixer css/styleguide.css
```

## Features and bugs

Please file feature requests and bugs at the [issue tracker][tracker].

###License###

    Copyright 2015 Michael Mitterer (office@mikemitterer.at),
    IT-Consulting and Development Limited, Austrian Branch

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing,
    software distributed under the License is distributed on an
    "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    either express or implied. See the License for the specific language
    governing permissions and limitations under the License.


If this plugin is helpful for you - please [(Circle)](http://gplus.mikemitterer.at/) me
or **star** this repo here on GitHub


[tracker]: https://github.com/MikeMitterer/dart-wsk-material/issues
[wskmaterial]: https://github.com/google/web-starter-kit/tree/material-sprint
[wskdemo]: http://wsk.mikemitterer.at/
[wskangular]: https://github.com/MikeMitterer/dart-wsk-angular
[themingsample]: https://github.com/MikeMitterer/dart-wsk-angular/tree/master/example/styleguide/assets/scss
[samples]: https://github.com/MikeMitterer/dart-wsk-material/tree/master/example
[promoimage]: https://github.com/MikeMitterer/dart-wsk-material/blob/master/lib/images/wsk.mikemitterer.at-720px.jpg?raw=true
